elephant.spike\_train\_generation.StationaryLogNormalProcess
============================================================

.. currentmodule:: elephant.spike_train_generation

.. autoclass:: StationaryLogNormalProcess
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StationaryLogNormalProcess.__init__
      ~StationaryLogNormalProcess.generate_n_spiketrains
      ~StationaryLogNormalProcess.generate_spiketrain
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StationaryLogNormalProcess.expected_cv
      ~StationaryLogNormalProcess.mu
      ~StationaryLogNormalProcess.t_start
      ~StationaryLogNormalProcess.t_stop
      ~StationaryLogNormalProcess.isi_generator
   
   